@@ -1,5 +1,6 @@
 from widgets.streamlit.resource.base import StResource # noqa
 from widgets.streamlit.resource.dataframe import StDataFrame # noqa
+from widgets.streamlit.resource.expander import StExpander # noqa
 from widgets.streamlit.resource.value import StCheckbox # noqa
 from widgets.streamlit.resource.value import StFloat # noqa
 from widgets.streamlit.resource.value import StInteger # noqa
@@ -7,5 +8,3 @@ from widgets.streamlit.resource.value import StSelectString # noqa
 from widgets.streamlit.resource.value import StString # noqa
 from widgets.streamlit.resource.value import StSlider # noqa
 from widgets.streamlit.widget.base import StreamlitWidget # noqa
-from widgets.streamlit.resource_list.base import StResourceList # noqa
-from widgets.streamlit.resource_list.expander import StExpander # noqa
